@@ -528,7 +528,7 @@ usage() {
     echo ""
 }
 
-NVIDIA_BUG_REPORT_CHANGE='$Change: 35839577 $'
+NVIDIA_BUG_REPORT_CHANGE='$Change: 36347749 $'
 NVIDIA_BUG_REPORT_VERSION=`echo "$NVIDIA_BUG_REPORT_CHANGE" | tr -c -d "[:digit:]"`
 
 # Set the default filename so that it won't be empty in the usage message
@@ -1852,7 +1852,18 @@ if [ $? -eq 0 -a -x "$systemctl" ]; then
         echo ""
     ) 2> /dev/null | $GZIP_CMD >> $LOG_FILENAME
 fi
-
+# get nvidia-imex-ctl output
+imexctl=`which nvidia-imex-ctl 2> /dev/null | head -n 1`
+if [ $? -eq 0 -a -x "$imexctl" ]; then
+    cmd="$imexctl -N"
+    (
+        echo "____________________________________________"
+        echo ""
+        echo "$cmd"
+        $cmd
+        echo ""
+    ) 2> /dev/null | $GZIP_CMD >> $LOG_FILENAME
+fi
 
 # Print information about the libglvnd libraries
 (
